Package: metaMS
Type: Package
Title: MS-based metabolomics annotation pipeline
Version: 1.48.0
Authors@R: c(person("Ron", "Wehrens", role = "aut", comment =
        c("author of GC-MS part", "Initial Maintainer"), email = "ron.wehrens@gmail.com"),
        person("Pietro", "Franceschi", role = "aut", comment = "author
        of LC-MS part"), person("Nir", "Shahaf", role = "ctb"),
        person("Matthias", "Scholz", role = "ctb"), person("Georg",
        "Weingart", role = "ctb", comment = "development of GC-MS
        approach"), person("Elisabete", "Carvalho", role = "ctb",
        comment = "testing and feedback of GC-MS pipeline"), person("Yann", "Guitton", role=c("ctb","cre"), email="yann.guitton@gmail.com", comment=c(ORCID = "0000-0002-4479-0636")), person("Julien", "Saint-Vanne", role="ctb"))
Depends: R (>= 4.0), methods, CAMERA, xcms (>= 1.35)
Imports: Matrix, tools, robustbase, BiocGenerics, graphics, stats,
        utils
Suggests: metaMSdata, RUnit
Description: MS-based metabolomics data processing and compound
        annotation pipeline.
URL: https://github.com/yguitton/metaMS
License: GPL (>= 2)
biocViews: ImmunoOncology, MassSpectrometry, Metabolomics
Encoding: UTF-8
RoxygenNote: 7.1.0
git_url: https://git.bioconductor.org/packages/metaMS
git_branch: RELEASE_3_23
git_last_commit: 82c42f6
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:08:59 UTC; biocbuild
Author: Ron Wehrens [aut] (author of GC-MS part, Initial Maintainer),
  Pietro Franceschi [aut] (author of LC-MS part),
  Nir Shahaf [ctb],
  Matthias Scholz [ctb],
  Georg Weingart [ctb] (development of GC-MS approach),
  Elisabete Carvalho [ctb] (testing and feedback of GC-MS pipeline),
  Yann Guitton [ctb, cre] (ORCID:
    <https://orcid.org/0000-0002-4479-0636>),
  Julien Saint-Vanne [ctb]
Maintainer: Yann Guitton <yann.guitton@gmail.com>
